# MLOPTIFLOW

Dynamic MLOps Framework with Integrated CLI for Automated ML Project Inception, Kafka-Driven Real-Time Model Monitoring, and Adaptive Canary Deployment Architectures


## Installation

1. create a new virtual environment with python ^3.11 and activate it

2. install mloptiflow:

```bash
pip install mloptiflow
```

3. initialize a new project and choose a name and paradigm (currently supported paradigms are: `tabular_regression`, `tabular_classification`):

```bash
mloptiflow init <your-project-name> --paradigm=<paradigm-name>
```

4. `cd` into your project directory:

```bash
cd <your-project-name>
```

5. install dependencies:

```bash
poetry install
```

or if using `pip`:

```bash
pip install -r requirements.txt
```

## Usage
- TBA

## Support
- TBA

## Roadmap
- TBA

## Contributing
- TBA


## License
MIT
